from fastapi import APIRouter, Depends
from sqlalchemy.orm import Session

from app.db.deps import get_db

router = APIRouter()


@router.get("")
def health_check(db: Session = Depends(get_db)):
    """
    Health check endpoint to verify API and database are running.
    """
    try:
        # Check if DB connection is working
        db.execute("SELECT 1")
        db_status = "healthy"
    except Exception as e:
        db_status = f"unhealthy: {str(e)}"
    
    return {
        "status": "healthy",
        "database": db_status,
        "version": "1.0.0"
    }