from typing import Optional
from datetime import datetime
from pydantic import BaseModel


# Shared properties
class PreferenceBase(BaseModel):
    recipient_name: str
    interests: Optional[str] = None
    hobbies: Optional[str] = None
    favorite_colors: Optional[str] = None
    clothing_size: Optional[str] = None
    dislikes: Optional[str] = None


# Properties to receive via API on creation
class PreferenceCreate(PreferenceBase):
    pass


# Properties to receive via API on update
class PreferenceUpdate(PreferenceBase):
    recipient_name: Optional[str] = None


class PreferenceInDBBase(PreferenceBase):
    id: int
    user_id: int
    created_at: datetime
    updated_at: Optional[datetime] = None

    class Config:
        from_attributes = True


# Additional properties to return via API
class Preference(PreferenceInDBBase):
    pass